aboutsummaryrefslogtreecommitdiffstats
path: root/lisp
diff options
context:
space:
mode:
authorCarsten Dominik <[email protected]>2002-07-22 10:38:32 +0000
committerCarsten Dominik <[email protected]>2002-07-22 10:38:32 +0000
commit6fbeb4293696fae4524135e41c23fd78d566eeb0 (patch)
treee8cb868ed38728598a1978e6f67b41042ed56b7e /lisp
parentb0e057bc0a65607340557686ca78d4489977455c (diff)
Updated to reftex 4.17
Diffstat (limited to 'lisp')
-rw-r--r--lisp/ChangeLog236
-rw-r--r--lisp/textmodes/reftex-auc.el4
-rw-r--r--lisp/textmodes/reftex-cite.el128
-rw-r--r--lisp/textmodes/reftex-dcr.el4
-rw-r--r--lisp/textmodes/reftex-global.el4
-rw-r--r--lisp/textmodes/reftex-index.el7
-rw-r--r--lisp/textmodes/reftex-parse.el10
-rw-r--r--lisp/textmodes/reftex-ref.el4
-rw-r--r--lisp/textmodes/reftex-sel.el4
-rw-r--r--lisp/textmodes/reftex-toc.el27
-rw-r--r--lisp/textmodes/reftex-vars.el116
-rw-r--r--lisp/textmodes/reftex.el53
12 files changed, 361 insertions, 236 deletions
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index b67c3d795f..c5fce8ea26 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,51 @@
+2002-07-22 Carsten Dominik <[email protected]>
+
+ * textmodes/reftex-vars.el (reftex-index-verify-function): New
+ option.
+ (reftex-bibliography-commands): New option.
+ (reftex-toc-split-windows-horizontally): New option
+ (reftex-toc-split-windows-horizontally-fraction): New option
+ (reftex-include-file-commands): New option.
+ (reftex-cite-format-builtin): Added ?n for nocite.
+
+ * textmodes/reftex-index.el (reftex-query-index-phrase): Use
+ `reftex-index-verify-function'.
+
+ * textmodes/reftex-toc.el (reftex-re-enlarge): Handle horizontal
+ splitting.
+ (reftex-toc): Handle horizontal splitting
+ (reftex-last-window-width): New variable.
+
+ * textmodes/reftex-parse.el (reftex-locate-bibliography-files):
+ Use `reftex-bibliography-commands'.
+ (reftex-locate-bibliography-files): Regexp relaxed to allow for
+ cases where \bibliography is not the first thing on the line.
+
+ * textmodes/reftex.el (reftex-compile-variables): Use
+ `reftex-include-file-commands'.
+ (reftex-type-query-prompt): Changed defconst to defvar.
+ (reftex-type-query-help): likewise
+ (reftex-typekey-to-format-alist): likewise
+ (reftex-typekey-to-prefix-alist): likewise
+ (reftex-env-or-mac-alist):
+ (reftex-special-env-parsers): likewise
+ (reftex-label-mac-list): likewise
+ (reftex-label-env-list): likewise
+ (reftex-typekey-list): likewise
+ (reftex-words-to-typekey-alist): likewise
+ (reftex-key-to-index-macro-alist): likewise
+ (reftex-query-index-macro-prompt): likewise
+ (reftex-query-index-macro-help): likewise
+ (reftex-no-follow-message): likewise
+ (reftex-no-info-message): likewise
+ (reftex-mode): Define systax table for bibtex parsing.
+ (reftex-syntax-table-for-bib): Syntax table for bibtex parsing.
+
+ * textmodes/reftex-cite.el (reftex-format-names): %a as name
+ format lists all names.
+ (reftex-parse-bibtex-entry): Use `reftex-syntax-table-for-bib'.
+ (reftex-with-special-syntax-for-bib): new macro.
+
2002-07-21 Kai Gro,b_(Bjohann <[email protected]>
* net/tramp.el: Bump version to 2.0.2.
@@ -384,7 +432,7 @@
* calendar/timeclock.el (timeclock-in): Handle the case where no
log file exists (ie the very first call).
-2002-07-13 Kai Gro,A_(Bjohann <[email protected]>
+2002-07-13 Kai Gro�johann <[email protected]>
* net/ange-ftp.el: Do not hook into file-name-handler-alist, this
is done by Tramp.
@@ -460,7 +508,7 @@
(Macedoninan), "ru" (Russian), and "sp" (Serbian with Cyrillic
alphabet) to "Cyrillic-ISO".
-2002-07-11 Kai Gro,A_(Bjohann <[email protected]>
+2002-07-11 Kai Gro�johann <[email protected]>
* net/tramp.el (tramp-default-method): New default method "sm"
which I guess to be good for most people.
@@ -873,7 +921,7 @@
(uniquify-delayed-rationalize-file-buffer-names):
Rename from delayed-uniquify-rationalize-file-buffer-names.
-2002-06-27 Kai Gro,A_(Bjohann <[email protected]>
+2002-06-27 Kai Gro�johann <[email protected]>
* net/tramp.el (tramp-file-name-structure)
(tramp-multi-file-name-hop-structure): Split for easier readability.
@@ -922,7 +970,7 @@
* dired.el (dired-find-alternate-file): Mark as disabled.
-2002-06-25 Kai Gro,A_(Bjohann <[email protected]>
+2002-06-25 Kai Gro�johann <[email protected]>
* net/tramp.el (tramp-ftp-method): New user option.
(tramp-invoke-ange-ftp): New function to forward calls to Ange-FTP.
@@ -1010,7 +1058,7 @@
* progmodes/f90.el (f90-do-auto-fill): Respect the value of
comment-auto-fill-only-comments.
-2002-06-21 Kai Gro,A_(Bjohann <[email protected]>
+2002-06-21 Kai Gro�johann <[email protected]>
* net/ange-ftp.el (backup-buffer): Delete `ange-ftp' property.
This is not a handled operation.
@@ -1496,7 +1544,7 @@
* select.el (xselect-convert-to-string): If VALUE is a string,
return a cons of TYPE and the string.
-2002-06-05 Pavel Jan,Am(Bk <[email protected]>
+2002-06-05 Pavel Jan�k <[email protected]>
* language/cyrillic.el (cyrillic-alternativnyj-decode-table):
Fix the table to contain correct characters.
@@ -1932,7 +1980,7 @@
(mail-default-directory): New user option.
(mail, mail-recover): Use that option.
-2002-05-20 Kai Gro,A_(Bjohann <[email protected]>
+2002-05-20 Kai Gro�johann <[email protected]>
* international/mule.el (auto-coding-alist): Use emacs-mule
for auto-save files.
@@ -2110,7 +2158,7 @@
(dabbrev-upcase-means-case-search): Doc fix.
(dabbrev-case-replace): Fix custom tags and docs.
-2002-05-14 Jochen K,A|(Bpper <[email protected]>
+2002-05-14 Jochen K�pper <[email protected]>
* calc/calc-units.el (math-standard-units): Update from CODATA.
@@ -2172,7 +2220,7 @@
(occur-engine): If there are no more matches, then finish
searching the current buffer.
-2002-05-12 Pavel Jan,Am(Bk <[email protected]>
+2002-05-12 Pavel Jan�k <[email protected]>
* net/ange-ftp.el (ange-ftp-try-passive-mode)
(ange-ftp-passive-host-alist): Change :version attributes to be
@@ -2214,7 +2262,7 @@
* subr.el (functionp): Catch errors in indirect-function.
-2002-05-12 Pavel Jan,Am(Bk <[email protected]>
+2002-05-12 Pavel Jan�k <[email protected]>
* net/ldap.el (ldap-search-internal): Unfold folded lines before
parsing.
@@ -2297,7 +2345,7 @@
* wid-edit.el (checkbox): New check-mark image.
-2002-05-08 Pavel Jan,Am(Bk <[email protected]>
+2002-05-08 Pavel Jan�k <[email protected]>
* filesets.el (filesets-running-xemacs): Fix last change.
@@ -2317,7 +2365,7 @@
(filesets-menu-path, filesets-menu-before, filesets-menu-in-menu):
Defvar them to nil if running in Emacs.
-2002-05-08 Pavel Jan,Am(Bk <[email protected]>
+2002-05-08 Pavel Jan�k <[email protected]>
* textmodes/flyspell.el (make-flyspell-overlay): Add help text
to flyspell overlays.
@@ -2572,7 +2620,7 @@
Only interpret delete-selection property if mark-active.
(cua-mode): Fixed require in defcustom.
-2002-05-01 Pavel Jan,Am(Bk <[email protected]>
+2002-05-01 Pavel Jan�k <[email protected]>
* calendar/cal-menu.el (cal-menu-x-popup-menu): Fix argument of
error call.
@@ -2707,7 +2755,7 @@
* language/viet-util.el: Update Commentary section.
-2002-04-29 Pavel Jan,Am(Bk <[email protected]>
+2002-04-29 Pavel Jan�k <[email protected]>
* filesets.el (filesets-data): Doc fix.
(filesets-running-xemacs): Define even when compiling.
@@ -2772,7 +2820,7 @@
* replace.el (occur-revert-arguments):
Renamed from occur-revert-properties. All uses changed.
-2002-04-28 Pavel Jan,Am(Bk <[email protected]>
+2002-04-28 Pavel Jan�k <[email protected]>
* recentf.el (recentf-menu-before): Use string to specify path in
the menu.
@@ -3149,7 +3197,7 @@
when finding the end. Take more care in analyzing the results
of intangibility after line-move-to-column.
-2002-04-22 Pavel Jan,Am(Bk <[email protected]>
+2002-04-22 Pavel Jan�k <[email protected]>
* international/mule-diag.el (list-input-methods-1): Doc fix
(LEIM is now part of the standard distribution).
@@ -4145,7 +4193,7 @@
* term.el (term-emulate-terminal): Fix last change.
-2002-04-16 Pavel Jan,Am(Bk <[email protected]>
+2002-04-16 Pavel Jan�k <[email protected]>
* bindings.el (mode-line-mode-menu): Update names to reflect
latest changes.
@@ -4221,7 +4269,7 @@
(exchange-point-and-mark): Temporarily enable transient-mark-mode
if prefix arg.
-2002-04-14 Pavel Jan,Am(Bk <[email protected]>
+2002-04-14 Pavel Jan�k <[email protected]>
* speedbar.el (speedbar-tag-hierarchy-method)
(speedbar-toggle-updates, speedbar-toggle-images): Doc fixes.
@@ -4231,7 +4279,7 @@
* textmodes/sgml-mode.el (sgml-parse-tag-backward): Fix to work at
beginning of buffer.
-2002-04-14 Pavel Jan,Am(Bk <[email protected]>
+2002-04-14 Pavel Jan�k <[email protected]>
* speedbar.el (speedbar-generic-item-info)
(speedbar-sort-tags): Doc fix.
@@ -4260,7 +4308,7 @@
(gamegrid-add-score): Just dispatch on `system-type' to one of the
previous two functions.
-2002-04-13 Pavel Jan,Am(Bk <[email protected]>
+2002-04-13 Pavel Jan�k <[email protected]>
* iswitchb.el: Update commentary to include new function
iswitchb-exclude-nonmatching.
@@ -4325,7 +4373,7 @@
(fill-region-as-paragraph): Compare to `to' rather than eobp.
(fill-paragraph): Don't rebind fill-paragraph-function.
-2002-04-11 Pavel Jan,Am(Bk <[email protected]>
+2002-04-11 Pavel Jan�k <[email protected]>
* menu-bar.el (menu-bar-adv-search-menu): Add incremental search.
@@ -4439,7 +4487,7 @@
Use sgml-parse-tag-backward to find start point.
(sgml-looking-back-at): Doc fix.
-2002-04-09 Pavel Jan,Am(Bk <[email protected]>
+2002-04-09 Pavel Jan�k <[email protected]>
* isearch.el (isearch-message-prefix): Use minibuffer-prompt face
for prompt.
@@ -4488,7 +4536,7 @@
* vc-cvs.el (vc-cvs-valid-version-number-p): New function.
(vc-cvs-checkin): Use it.
-2002-04-08 Pavel Jan,Am(Bk <[email protected]>
+2002-04-08 Pavel Jan�k <[email protected]>
* files.el (display-time-string): Fix last change.
@@ -4503,7 +4551,7 @@
default-process-coding-system.
(coding-system-change-text-conversion): Fix case where CODING is nil.
-2002-04-07 Pavel Jan,Am(Bk <[email protected]>
+2002-04-07 Pavel Jan�k <[email protected]>
* subr.el (play-sound): Move here from simple.el.
@@ -4530,7 +4578,7 @@
* textmodes/xml-lite.el: Remove.
-2002-04-05 Pavel Jan,Am(Bk <[email protected]>
+2002-04-05 Pavel Jan�k <[email protected]>
* simple.el (play-sound): New function (uses play-sound-internal).
@@ -4554,7 +4602,7 @@
* textmodes/sgml-mode.el: Add missing require.
(sgml-lexical-context): Fix up CDATA detection for boundary cases.
-2002-04-03 Kai Gro,A_(Bjohann <[email protected]>
+2002-04-03 Kai Gro�johann <[email protected]>
* pcvs.el (cvs-mode-previous-line, cvs-mode-next-line): Move to
spot indicated by text property `cvs-goal-column', if present.
@@ -4622,7 +4670,7 @@
(sgml-parse-tag-backward): Extend support for CDATA to include
conditional sections.
-2002-04-03 Pavel Jan,Am(Bk <[email protected]>
+2002-04-03 Pavel Jan�k <[email protected]>
* cus-start.el: Rename `autoselect-window' to
`mouse-autoselect-window'.
@@ -4696,7 +4744,7 @@
(xml-lite-parse-tag-backward): Simplify parsing by assuming we
always start within text. Make use of sgml-unclosed-tag-p.
-2002-04-01 Ville Skytt,Ad(B <[email protected]>
+2002-04-01 Ville Skytt� <[email protected]>
* tcl.el (tcl-imenu-generic-expression): New value.
(tcl-imenu-create-index-function): Function deleted.
@@ -4706,7 +4754,7 @@
(inferior-tcl-mode): Doc fix.
Change not legally significant.
-2002-04-01 Pavel Jan,Am(Bk <[email protected]>
+2002-04-01 Pavel Jan�k <[email protected]>
* cus-start.el: Rename `x-autoselect-window' to `autoselect-window'.
@@ -4907,7 +4955,7 @@
for comments.
(xml-lite-in-string-p): Simplify.
-2002-03-27 Pavel Jan,Am(Bk <[email protected]>
+2002-03-27 Pavel Jan�k <[email protected]>
* allout.el (outline-layout): Doc fix.
@@ -4975,7 +5023,7 @@
* subr.el (substring-no-properties): Function deleted (now in C).
-2002-03-25 Pavel Jan,Am(Bk <[email protected]>
+2002-03-25 Pavel Jan�k <[email protected]>
* mwheel.el (mouse-wheel-mode): Use global-set-key and
global-unset-key.
@@ -5016,7 +5064,7 @@
fore- and background colors of the faces we create, since facemenu
doesn't.
-2002-03-24 Pavel Jan,Am(Bk <[email protected]>
+2002-03-24 Pavel Jan�k <[email protected]>
* mwheel.el (mouse-wheel-mode): Use the result of
current-global-map instead of the variable `global-map'.
@@ -5071,7 +5119,7 @@
* mail/emacsbug.el (report-emacs-bug-hook): Remove submitter
directions as the last action.
-2002-03-21 Pavel Jan,Am(Bk <[email protected]>
+2002-03-21 Pavel Jan�k <[email protected]>
* startup.el (fancy-splash-tail, normal-splash-screen):
Update copyright.
@@ -5259,7 +5307,7 @@
<top-level>: Remove the setup for all known codepages: it seems
to cause crashes in the CCL driver.
-2002-03-16 Pavel Jan,Am(Bk <[email protected]>
+2002-03-16 Pavel Jan�k <[email protected]>
* textmodes/bibtex.el (bibtex-sort-ignore-string-entries)
(bibtex-entry-field-alist): Doc fix.
@@ -5277,7 +5325,7 @@
* files.el (load-completion): New function.
(load-library): Use it.
-2002-03-15 Pavel Jan,Am(Bk <[email protected]>
+2002-03-15 Pavel Jan�k <[email protected]>
* calendar/cal-french.el (calendar-goto-french-date): Fix prompt
to match the actual code.
@@ -5420,7 +5468,7 @@
* comint.el: Remove documentation on setting up pcomplete.
-2002-03-11 Pavel Jan,Am(Bk <[email protected]>
+2002-03-11 Pavel Jan�k <[email protected]>
* font-lock.el (java-font-lock-extra-types): Add "URL" as separate
item. Doc fix.
@@ -5540,7 +5588,7 @@
(hif-conditional): New function to evaluate a conditional
expression.
-2002-03-06 Pavel Jan,Am(Bk <[email protected]>
+2002-03-06 Pavel Jan�k <[email protected]>
* language/czech.el ("Czech"): Fix the documentation.
@@ -5603,7 +5651,7 @@
(mode-line-inactive, header-line): Move the `t' section to the
beginning so the `:inherit' setting can be shared.
-2002-03-04 Pavel Jan,Am(Bk <[email protected]>
+2002-03-04 Pavel Jan�k <[email protected]>
* net/snmp-mode.el: Require tempo when compiling to prevent
warnings. Update copyright notice.
@@ -5723,7 +5771,7 @@
* font-lock.el (java-font-lock-extra-types):
Match java.net.URL, etc.
-2002-02-28 Pavel Jan,Am(Bk <[email protected]>
+2002-02-28 Pavel Jan�k <[email protected]>
* hexl.el (hexl-options): Doc fix.
Update Commentary section.
@@ -6003,7 +6051,7 @@
* progmodes/tcl.el (tcl-do-fill-paragraph): Find and fill on more
natural paragraph boundaries. Don't fail at beginning of buffer.
-2002-02-20 Pavel Jan,Am(Bk <[email protected]>
+2002-02-20 Pavel Jan�k <[email protected]>
* tar-mode.el (tar-next-line, tar-previous-line): Add doc string,
call the argument "arg" to match plain next-line and
@@ -6067,7 +6115,7 @@
* mail/uce.el (uce-reply-to-uce): Fix incorrect behavior when
invoked from Rmail with full headers displayed.
-2002-02-17 Kai Gro,A_(Bjohann <[email protected]>
+2002-02-17 Kai Gro�johann <[email protected]>
* emacs-lisp/lisp.el (mark-defun): Don't leave multiple marks
when repeated.
@@ -6083,7 +6131,7 @@
* textmodes/flyspell.el (flyspell): Add to ispell group.
-2002-02-17 Kai Gro,A_(Bjohann <[email protected]>
+2002-02-17 Kai Gro�johann <[email protected]>
* emacs-lisp/lisp.el (mark-sexp): Don't leave multiple marks when
repeated.
@@ -6107,7 +6155,7 @@
* cus-start.el: Add automatic-hscroll-margin and
automatic-hscroll-step.
-2002-02-16 Pavel Jan,Am(Bk <[email protected]>
+2002-02-16 Pavel Jan�k <[email protected]>
* cus-start.el (x-autoselect-window): Allow customization.
@@ -6204,7 +6252,7 @@
* menu-bar.el (menu-bar-tools-menu): Add an item for Calculator.
-2002-02-15 Kai Gro,A_(Bjohann <[email protected]>
+2002-02-15 Kai Gro�johann <[email protected]>
* simple.el (mark-word): Mark more if repeated.
* textmodes/paragraphs.el (mark-paragraph): Ditto.
@@ -6305,7 +6353,7 @@
* cus-start.el: Don't warn about "x-*" symbols when building a
non-GUI version.
-2002-02-11 Pavel Jan,Am(Bk <[email protected]>
+2002-02-11 Pavel Jan�k <[email protected]>
* strokes.el (strokes-do-stroke, strokes-do-complex-stroke):
Doc fix.
@@ -6330,7 +6378,7 @@
(dump-charsets, dump-codings): Deleted (obsolete).
From Dave Love <[email protected]>.
-2002-02-10 Pavel Jan,Am(Bk <[email protected]>
+2002-02-10 Pavel Jan�k <[email protected]>
* menu-bar.el (menu-bar-showhide-menu): Rename functions for toggling.
@@ -6353,7 +6401,7 @@
* ediff.el: Typo in comment.
-2002-02-09 Pavel Jan,Am(Bk <[email protected]>
+2002-02-09 Pavel Jan�k <[email protected]>
* menu-bar.el (menu-bar-options-save): Take care of
line-number-mode and column-number-mode variables.
@@ -6430,7 +6478,7 @@
* subr.el (global-set-key, local-set-key): Accept a symbol for the
KEY argument (like define-key).
-2002-02-06 Pavel Jan,Am(Bk <[email protected]>
+2002-02-06 Pavel Jan�k <[email protected]>
* textmodes/flyspell.el (flyspell-insert-function): Doc fix.
@@ -6511,7 +6559,7 @@
* cus-edit.el (customize-mark-to-save): New function.
* menu-bar.el (menu-bar-options-save): Rewrote.
-2002-02-05 Pavel Jan,Am(Bk <[email protected]>
+2002-02-05 Pavel Jan�k <[email protected]>
* cus-start.el (x-use-underline-position-properties):
Allow customization.
@@ -6544,11 +6592,11 @@
* window.el (save-selected-window): Move macro before first use.
(balance-windows): Fix misplaced parenthesis.
-2002-02-03 Pavel Jan,Am(Bk <[email protected]>
+2002-02-03 Pavel Jan�k <[email protected]>
* calculator.el (calculator-displayers): Doc fixes.
-2002-02-03 Pavel Jan,Am(Bk <[email protected]>
+2002-02-03 Pavel Jan�k <[email protected]>
* menu-bar.el (menu-bar-help-menu): Use different text for tool-tip.
(menu-bar-options-save): Save also the value of `display-time-mode'.
@@ -6587,7 +6635,7 @@
looking for X-Coding-System header, and restore the pruned state
before returning.
-2002-02-02 Pavel Jan,Am(Bk <[email protected]>
+2002-02-02 Pavel Jan�k <[email protected]>
* cus-edit.el (customize-save-variable): Fix typo in prompt.
@@ -6676,7 +6724,7 @@
* emulation/pc-select.el (pc-select-save-and-set-mode):
Properly use MODE-VAR.
-2002-01-29 Pavel Jan,Am(Bk <[email protected]>
+2002-01-29 Pavel Jan�k <[email protected]>
* menu-bar.el (menu-bar-help-menu): Change menu-item "Show Emacs
Version" to "About Emacs".
@@ -6693,7 +6741,7 @@
* calendar/calendar.el (generate-calendar-month): Doc fix.
-2002-01-27 Pavel Jan,Am(Bk <[email protected]>
+2002-01-27 Pavel Jan�k <[email protected]>
* time.el (display-time-mail-directory): New option.
(display-time-mail-function): Update doc-string.
@@ -6908,7 +6956,7 @@
with `byte-compile-dynamic'.
(ibuffer-default-directory, toplevel): Doc files.
-2002-01-20 Pavel Jan,Am(Bk <[email protected]>
+2002-01-20 Pavel Jan�k <[email protected]>
* tempo.el (tempo-define-template): Doc fix.
@@ -6925,7 +6973,7 @@
* term/w32-win.el (mouse-set-font): Use w32-list-proportional-fonts.
-2002-01-19 Pavel Jan,Am(Bk <[email protected]>
+2002-01-19 Pavel Jan�k <[email protected]>
* language/tibet-util.el (tibetan-decompose-region)
(tibetan-decompose-string): Fix typo in docstring.
@@ -7017,7 +7065,7 @@
* mail/feedmail.el (feedmail): Fix :link spec.
-2002-01-16 Pavel Jan,Am(Bk <[email protected]>
+2002-01-16 Pavel Jan�k <[email protected]>
* net/ldap.el (ldap-ldapsearch-prog): Default to OpenLDAP version
2 ldapsearch.
@@ -7134,7 +7182,7 @@
(comint-send-input): New arg NO-NEWLINE.
(comint-send-eof): Call comint-send-eof with NO-NEWLINE.
-2002-01-12 Pavel Jan,Am(Bk <[email protected]>
+2002-01-12 Pavel Jan�k <[email protected]>
* textmodes/flyspell.el (flyspell-check-pre-word-p):
Prevent delaying when executing keyboard macros.
@@ -7219,7 +7267,7 @@
* textmodes/flyspell.el (flyspell-mode-line-string): Fix custom type.
-2002-01-08 Pavel Jan,Am(Bk <[email protected]>
+2002-01-08 Pavel Jan�k <[email protected]>
* progmodes/ada-mode.el (ada-initialize-properties, ada-mode):
Do not use make-local-hook.
@@ -7235,7 +7283,7 @@
* ediff-hook.el: Add an autoload cookie.
-2002-01-08 Pavel Jan,Am(Bk <[email protected]>
+2002-01-08 Pavel Jan�k <[email protected]>
* net/eudcb-ph.el, net/ldap.el: New maintainer. New e-mail
address of the author.
@@ -7347,7 +7395,7 @@
* help-fns.el (describe-variable, describe-function):
Do save-excursion.
-2002-01-06 Pavel Jan,Am(Bk <[email protected]>
+2002-01-06 Pavel Jan�k <[email protected]>
* net/ldap.el (ldap-search-internal): Skip error message from
ldapsearch. Allow listing attribute names only. Do not open
@@ -7371,7 +7419,7 @@
* net/eudcb-ldap.el (eudc-attribute-display-method-alist):
Use proper attribute name labeledUri instead of deprecated labeledUrl.
-2002-01-05 Pavel Jan,Am(Bk <[email protected]>
+2002-01-05 Pavel Jan�k <[email protected]>
* net/eudc-hotlist.el (eudc-edit-hotlist): Avoid error when
editing an empty hotlist.
@@ -7432,7 +7480,7 @@
* mail/sendmail.el (mail-recover-1, mail-recover): Doc fix.
-2002-01-04 Pavel Jan,Am(Bk <[email protected]>
+2002-01-04 Pavel Jan�k <[email protected]>
* net/ldap.el (ldap-host-parameters-alist): Remove duplicated entry.
(ldap-ignore-attribute-codings): Change the default value to allow
@@ -7462,7 +7510,7 @@
does not exist, call mail-recover-1 to allow recovery from past
auto-saved drafts.
-2002-01-03 Pavel Jan,Am(Bk <[email protected]>
+2002-01-03 Pavel Jan�k <[email protected]>
* time.el (display-time-load-average-threshold): Fix defcustom
(add type and group).
@@ -7581,7 +7629,7 @@
* bindings.el (function-key-map): Don't bind shifted keypad
numeric keys.
-2002-01-02 Pavel Jan,Am(Bk <[email protected]>
+2002-01-02 Pavel Jan�k <[email protected]>
* enriched.el (enriched-handle-display-prop): Remove unused variables.
(enriched-mode): Doc fix.
@@ -7617,7 +7665,7 @@
* cus-edit.el (custom-face-edit-fix-value): New function.
(custom-face-edit): Use it, to convert :italic and :bold to new forms.
-2001-12-30 Pavel Jan,Am(Bk <[email protected]>
+2001-12-30 Pavel Jan�k <[email protected]>
* progmodes/octave-mod.el (octave-abbrev-table):
* progmodes/idlwave.el (idlwave-mode-abbrev-table):
@@ -7747,7 +7795,7 @@
* international/fontset.el: Don't require ind-util when compiling.
-2001-12-25 Pavel Jan,Am(Bk <[email protected]>
+2001-12-25 Pavel Jan�k <[email protected]>
* emulation/tpu-edt.el (tpu-reset-screen-size):
Use set-frame-height and set-frame-width instead of set-screen-height
@@ -7835,7 +7883,7 @@
* play/yow.el (yow): Use an arg to distinguish interactive calls,
not interactive-p.
-2001-12-22 Pavel Jan,Am(Bk <[email protected]>
+2001-12-22 Pavel Jan�k <[email protected]>
* emacs-lisp/elint.el (elint-unknown-builtin-args):
Remove mocklisp entries.
@@ -7861,7 +7909,7 @@
* textmodes/refill.el (refill-mode): Don't barf when redundantly
turning refill-mode off.
-2001-12-22 Pavel Jan,Am(Bk <[email protected]>
+2001-12-22 Pavel Jan�k <[email protected]>
* time.el (display-time-load-average-threshold): New variable.
(display-time-update): Use it.
@@ -8004,7 +8052,7 @@
(print-coding-system-briefly): Make printed output have a similar
format as describe-character-set.
-2001-12-20 Pavel Jan,Am(Bk <[email protected]>
+2001-12-20 Pavel Jan�k <[email protected]>
* play/blackbox.el (bb-member): Remove, use member instead.
(bb-delete): Remove, use delete instead.
@@ -8038,7 +8086,7 @@
* international/fontset.el: Require `ind-util' when compiling.
-2001-12-18 Pavel Jan,Am(Bk <[email protected]>
+2001-12-18 Pavel Jan�k <[email protected]>
* language/ethio-util.el (ethio-modify-vowel): Use char-to-string
instead of decompose-composite-char.
@@ -8256,7 +8304,7 @@
* newcomment.el (comment-indent): Jump to the middle of empty comments.
-2001-12-14 Pavel Jan,Am(Bk <[email protected]>
+2001-12-14 Pavel Jan�k <[email protected]>
* select.el (xselect-convert-to-class, xselect-convert-to-name):
Document.
@@ -8304,7 +8352,7 @@
* international/mule.el (set-auto-coding): Don't search for
"unibyte:" or "coding:" if set-auto-mode-1 returns nil.
-2001-12-13 Pavel Jan,Am(Bk <[email protected]>
+2001-12-13 Pavel Jan�k <[email protected]>
* mail/mailabbrev.el (mail-abbrevs-setup): Do not use make-local-hook.
@@ -8360,7 +8408,7 @@
* language/european.el: Remove autoload cookies. Fix registration
of diacritic composition function.
-2001-12-11 Pavel Jan,Am(Bk <[email protected]>
+2001-12-11 Pavel Jan�k <[email protected]>
* calendar/todo-mode.el: Require time-stamp.
@@ -8417,7 +8465,7 @@
Use `select-frame-set-input-focus'--needed when window manager
uses "click to focus" policy.
-2001-12-09 Pavel Jan,Am(Bk <[email protected]>
+2001-12-09 Pavel Jan�k <[email protected]>
* COPYING: Moved back.
@@ -8566,7 +8614,7 @@
* textmodes/picture.el (picture-mode-map): Don't use defconst
for a variable.
-2001-12-02 Pavel Jan,Am(Bk <[email protected]>
+2001-12-02 Pavel Jan�k <[email protected]>
* textmodes/reftex-index.el (reftex-index-mode):
Remove make-local-hook.
@@ -8631,12 +8679,12 @@
* man.el (Man-build-section-alist): Remove last Man-match-substring.
-2001-11-30 Kai Gro,A_(Bjohann <[email protected]>
+2001-11-30 Kai Gro�johann <[email protected]>
* textmodes/paragraphs.el (mark-paragraph): Clarify doc.
Clarify error message.
-2001-11-29 Kai Gro,A_(Bjohann <[email protected]>
+2001-11-29 Kai Gro�johann <[email protected]>
* textmodes/paragraphs.el (mark-paragraph): Allow prefix arg.
@@ -8690,7 +8738,7 @@
(Info-index): Use it. Add completion to the interactive spec.
(Info-menu-update): Simplify call to `Info-complete-menu-item'.
-2001-11-29 Pavel Jan,Am(Bk <[email protected]>
+2001-11-29 Pavel Jan�k <[email protected]>
* COPYING: Removed.
@@ -8707,7 +8755,7 @@
(register-char-codings): Use it to cope with generic chars in
safe-chars.
-2001-11-29 Pavel Jan,Am(Bk <[email protected]>
+2001-11-29 Pavel Jan�k <[email protected]>
* play/blackbox.el (blackbox-mode, blackbox): Doc fix.
@@ -8851,7 +8899,7 @@
* frame.el (show-trailing-whitespace): Remove :set argument (the
value was essentially identical to the defalt).
-2001-11-26 Pavel Jan,Am(Bk <[email protected]>
+2001-11-26 Pavel Jan�k <[email protected]>
* hexl.el (hexl-mode, hexl-follow-ascii): Remove make-local-hook.
@@ -8915,7 +8963,7 @@
* help-funs.el (describe-syntax): Put (interactive) after doc string.
-2001-11-26 Pavel Jan,Am(Bk <[email protected]>
+2001-11-26 Pavel Jan�k <[email protected]>
* international/quail.el (quail-help): Require help-mode in
top-level instead.
@@ -8986,12 +9034,12 @@
* language/devan-util.el: Comment out parts of the file
which apparently are garbled.
-2001-11-25 Pavel Jan,Am(Bk <[email protected]>
+2001-11-25 Pavel Jan�k <[email protected]>
* mail/smtpmail.el (smtpmail-deduce-address-list): Don't use
insert-string.
-2001-11-25 Pavel Jan,Am(Bk <[email protected]>
+2001-11-25 Pavel Jan�k <[email protected]>
* play/snake.el (snake-mode): Remove make-local-hook.
@@ -9118,7 +9166,7 @@
* international/encoded-kb.el: Don't alter minor-map-alist.
-2001-11-20 Kai Gro,A_(Bjohann <[email protected]>
+2001-11-20 Kai Gro�johann <[email protected]>
* files.el (auto-save-file-name-transforms): Put remote files in
temporary-file-directory rather than /tmp.
@@ -9476,7 +9524,7 @@
Don't recognize a "telephone number" at the beginning of the name.
(mail-extr-leading-garbage): Match non-word characters only.
-2001-11-16 Pavel Jan,Am(Bk <[email protected]>
+2001-11-16 Pavel Jan�k <[email protected]>
* startup.el (command-line-processed): Doc fix.
@@ -9504,7 +9552,7 @@
(multiple-value-apply, nth-value): Use defsubst rather than defalias
to get better doc strings.
-2001-11-15 Pavel Jan,Am(Bk <[email protected]>
+2001-11-15 Pavel Jan�k <[email protected]>
* derived.el: Fix autoload cookie.
@@ -9699,7 +9747,7 @@
(log-view-current-tag): Take an optional `where' arg.
(log-view-diff): New user command.
-2001-11-12 Pavel Jan,Am(Bk <[email protected]>
+2001-11-12 Pavel Jan�k <[email protected]>
* progmodes/cpp.el (cpp-choose-face): Fix typo.
@@ -9739,7 +9787,7 @@
* calc/calc-ext.el (calc-init-extensions): Update autoload names
to match files renamed on initial calc import.
-2001-11-12 Pavel Jan,Am(Bk <[email protected]>
+2001-11-12 Pavel Jan�k <[email protected]>
* textmodes/flyspell.el (flyspell-default-dictionary):
Fix previous change.
@@ -9782,7 +9830,7 @@
2001-11-11 Colin Walters <[email protected]>
The following changes are based on patches from
- Eli Zaretskii <[email protected]>, Kai Gro,A_(Bjohann
+ Eli Zaretskii <[email protected]>, Kai Gro�johann
<[email protected]>, and others.
* calc/calc.el (toplevel): Require calc-macs.
@@ -9851,7 +9899,7 @@
(radio-button-choice): Ditto.
(editable-list): Ditto.
-2001-11-09 Pavel Jan,Am(Bk <[email protected]>
+2001-11-09 Pavel Jan�k <[email protected]>
* play/gomoku.el: Move definitions of constants to the beginning
of file, before their use.
@@ -10127,7 +10175,7 @@
(debugger-setup-buffer): Call it.
(debugger-mode-map): Bind RET and mouse-2.
-2001-10-31 Pavel Jan,Am(Bk <[email protected]>
+2001-10-31 Pavel Jan�k <[email protected]>
* startup.el: Document command line option --no-window-system
instead of --no-windows.
@@ -10270,7 +10318,7 @@
Report numbers of files skipped and failed too.
(byte-compile-file): Return 'no-byte-compile for skipped files.
-2001-10-29 Kai Gro,A_(Bjohann <[email protected]>
+2001-10-29 Kai Gro�johann <[email protected]>
* log-view.el (log-view-mode-map): Bind `M-n' and `M-p', not `M n'
and `M p'.
@@ -10620,7 +10668,7 @@
* progmodes/compile.el (compilation-set-window-height):
Select old window only if it's still live.
-2001-10-22 Pavel Jan,Am(Bk <[email protected]>
+2001-10-22 Pavel Jan�k <[email protected]>
* help-mode.el (help-buffer): Remove debugging code.
From Stefan Monnier <[email protected]>.
diff --git a/lisp/textmodes/reftex-auc.el b/lisp/textmodes/reftex-auc.el
index 840bb88978..4546651da9 100644
--- a/lisp/textmodes/reftex-auc.el
+++ b/lisp/textmodes/reftex-auc.el
@@ -1,8 +1,8 @@
;;; reftex-auc.el --- RefTeX's interface to AUC TeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
diff --git a/lisp/textmodes/reftex-cite.el b/lisp/textmodes/reftex-cite.el
index 37833be278..ebcfd99182 100644
--- a/lisp/textmodes/reftex-cite.el
+++ b/lisp/textmodes/reftex-cite.el
@@ -1,8 +1,8 @@
;;; reftex-cite.el --- creating citations with RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
@@ -53,6 +53,15 @@
;; Find bibtex files
+
+(defmacro reftex-with-special-syntax-for-bib (&rest body)
+ `(let ((saved-syntax (syntax-table)))
+ (unwind-protect
+ (progn
+ (set-syntax-table reftex-syntax-table-for-bib)
+ ,@body)
+ (set-syntax-table saved-syntax))))
+
(defun reftex-default-bibliography ()
;; Return the expanded value of `reftex-default-bibliography'.
;; The expanded value is cached.
@@ -193,63 +202,64 @@
(message "Scanning bibliography database %s" buffer1))
(set-buffer buffer1)
- (save-excursion
- (goto-char (point-min))
- (while (re-search-forward first-re nil t)
- (catch 'search-again
- (setq key-point (point))
- (unless (re-search-backward
- "\\(\\`\\|[\n\r]\\)[ \t]*@\\([a-zA-Z]+\\)[ \t\n\r]*[{(]" nil t)
- (throw 'search-again nil))
- (setq start-point (point))
- (goto-char (match-end 0))
- (condition-case nil
- (up-list 1)
- (error (goto-char key-point)
+ (reftex-with-special-syntax-for-bib
+ (save-excursion
+ (goto-char (point-min))
+ (while (re-search-forward first-re nil t)
+ (catch 'search-again
+ (setq key-point (point))
+ (unless (re-search-backward
+ "\\(\\`\\|[\n\r]\\)[ \t]*@\\([a-zA-Z]+\\)[ \t\n\r]*[{(]" nil t)
+ (throw 'search-again nil))
+ (setq start-point (point))
+ (goto-char (match-end 0))
+ (condition-case nil
+ (up-list 1)
+ (error (goto-char key-point)
(throw 'search-again nil)))
- (setq end-point (point))
-
- ;; Ignore @string, @comment and @c entries or things
- ;; outside entries
- (when (or (string= (downcase (match-string 2)) "string")
- (string= (downcase (match-string 2)) "comment")
- (string= (downcase (match-string 2)) "c")
- (< (point) key-point)) ; this means match not in {}
- (goto-char key-point)
- (throw 'search-again nil))
-
- ;; Well, we have got a match
- (setq entry (concat
- (buffer-substring start-point (point)) "\n"))
-
- ;; Check if other regexp match as well
- (setq re-list rest-re)
- (while re-list
- (unless (string-match (car re-list) entry)
- ;; nope - move on
- (throw 'search-again nil))
- (pop re-list))
-
- (setq alist (reftex-parse-bibtex-entry
- nil start-point end-point))
- (push (cons "&entry" entry) alist)
-
- ;; check for crossref entries
- (if (assoc "crossref" alist)
- (setq alist
- (append
- alist (reftex-get-crossref-alist alist))))
-
- ;; format the entry
- (push (cons "&formatted" (reftex-format-bib-entry alist))
- alist)
-
- ;; make key the first element
- (push (reftex-get-bib-field "&key" alist) alist)
-
- ;; add it to the list
- (push alist found-list))))
- (reftex-kill-temporary-buffers))))
+ (setq end-point (point))
+
+ ;; Ignore @string, @comment and @c entries or things
+ ;; outside entries
+ (when (or (string= (downcase (match-string 2)) "string")
+ (string= (downcase (match-string 2)) "comment")
+ (string= (downcase (match-string 2)) "c")
+ (< (point) key-point)) ; this means match not in {}
+ (goto-char key-point)
+ (throw 'search-again nil))
+
+ ;; Well, we have got a match
+ (setq entry (concat
+ (buffer-substring start-point (point)) "\n"))
+
+ ;; Check if other regexp match as well
+ (setq re-list rest-re)
+ (while re-list
+ (unless (string-match (car re-list) entry)
+ ;; nope - move on
+ (throw 'search-again nil))
+ (pop re-list))
+
+ (setq alist (reftex-parse-bibtex-entry
+ nil start-point end-point))
+ (push (cons "&entry" entry) alist)
+
+ ;; check for crossref entries
+ (if (assoc "crossref" alist)
+ (setq alist
+ (append
+ alist (reftex-get-crossref-alist alist))))
+
+ ;; format the entry
+ (push (cons "&formatted" (reftex-format-bib-entry alist))
+ alist)
+
+ ;; make key the first element
+ (push (reftex-get-bib-field "&key" alist) alist)
+
+ ;; add it to the list
+ (push alist found-list)))))
+ (reftex-kill-temporary-buffers))))
(setq found-list (nreverse found-list))
;; Sorting
@@ -390,6 +400,7 @@
(progn
(set-buffer (get-buffer-create " *RefTeX-scratch*"))
(fundamental-mode)
+ (set-syntax-table reftex-syntax-table-for-bib)
(erase-buffer)
(insert entry))
(widen)
@@ -834,6 +845,7 @@ While entering the regexp, completion on knows citation keys is possible.
(defun reftex-format-names (namelist n)
(let (last (len (length namelist)))
+ (if (= n 0) (setq n len))
(cond
((< len 1) "")
((= 1 len) (car namelist))
diff --git a/lisp/textmodes/reftex-dcr.el b/lisp/textmodes/reftex-dcr.el
index 8c179ff32b..c0af53a9bc 100644
--- a/lisp/textmodes/reftex-dcr.el
+++ b/lisp/textmodes/reftex-dcr.el
@@ -1,8 +1,8 @@
;;; reftex-dcr.el --- viewing cross references and citations with RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;;
;; This file is part of GNU Emacs.
diff --git a/lisp/textmodes/reftex-global.el b/lisp/textmodes/reftex-global.el
index 6810b80adf..d19b45d76d 100644
--- a/lisp/textmodes/reftex-global.el
+++ b/lisp/textmodes/reftex-global.el
@@ -1,8 +1,8 @@
;;; reftex-global.el --- operations on entire documents with RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
diff --git a/lisp/textmodes/reftex-index.el b/lisp/textmodes/reftex-index.el
index 660dcfaadc..5db364c371 100644
--- a/lisp/textmodes/reftex-index.el
+++ b/lisp/textmodes/reftex-index.el
@@ -1,8 +1,8 @@
;;; reftex-index.el --- index support with RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
@@ -1819,6 +1819,9 @@ both ends."
(unwind-protect
(while (re-search-forward re nil t)
(catch 'next-match
+ (if (and (fboundp reftex-index-verify-function)
+ (not (funcall reftex-index-verify-function)))
+ (throw 'next-match nil))
(setq match (match-string 0))
(setq mathp
(save-match-data
diff --git a/lisp/textmodes/reftex-parse.el b/lisp/textmodes/reftex-parse.el
index 1bb6a24bce..3a42bc7d85 100644
--- a/lisp/textmodes/reftex-parse.el
+++ b/lisp/textmodes/reftex-parse.el
@@ -1,8 +1,8 @@
;;; reftex-parse.el --- parser functions for RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;;
;; This file is part of GNU Emacs.
@@ -198,6 +198,7 @@ of master file."
toc-entry index-entry next-buf buf)
(catch 'exit
+ (debug)
(setq file-found (reftex-locate-file file "tex" master-dir))
(if (and (not file-found)
(setq buf (reftex-get-buffer-visiting file)))
@@ -334,7 +335,10 @@ of master file."
(save-excursion
(goto-char (point-min))
(if (re-search-forward
- "\\(\\`\\|[\n\r]\\)[ \t]*\\\\\\(no\\)?bibliography{[ \t]*\\([^}]+\\)" nil t)
+ (concat
+ "\\(\\`\\|[\n\r]\\)[^%]*\\\\\\("
+ (mapconcat 'identity reftex-bibliography-commands "\\|")
+ "\\){[ \t]*\\([^}]+\\)") nil t)
(setq files
(split-string (reftex-match-string 3)
"[ \t\n\r]*,[ \t\n\r]*")))))
diff --git a/lisp/textmodes/reftex-ref.el b/lisp/textmodes/reftex-ref.el
index 4db17b238b..982062e12f 100644
--- a/lisp/textmodes/reftex-ref.el
+++ b/lisp/textmodes/reftex-ref.el
@@ -1,8 +1,8 @@
;;; reftex-ref.el --- code to create labels and references with RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
diff --git a/lisp/textmodes/reftex-sel.el b/lisp/textmodes/reftex-sel.el
index 05aadeeb03..f59e2a1e03 100644
--- a/lisp/textmodes/reftex-sel.el
+++ b/lisp/textmodes/reftex-sel.el
@@ -1,8 +1,8 @@
;;; reftex-sel.el --- the selection modes for RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
diff --git a/lisp/textmodes/reftex-toc.el b/lisp/textmodes/reftex-toc.el
index 2ec1040d19..1568593981 100644
--- a/lisp/textmodes/reftex-toc.el
+++ b/lisp/textmodes/reftex-toc.el
@@ -1,8 +1,8 @@
;;; reftex-toc.el --- RefTeX's table of contents mode
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
@@ -72,6 +72,7 @@ Here are all local bindings.
"Stores the file name from which `reftex-toc' was called. For redo command.")
(defvar reftex-last-window-height nil)
+(defvar reftex-last-window-width nil)
(defvar reftex-toc-include-labels-indicator nil)
(defvar reftex-toc-include-index-indicator nil)
(defvar reftex-toc-max-level-indicator nil)
@@ -127,7 +128,7 @@ When called with a raw C-u prefix, rescan the document first."
(docstruct-symbol reftex-docstruct-symbol)
(xr-data (assq 'xr (symbol-value reftex-docstruct-symbol)))
(xr-alist (cons (cons "" (buffer-file-name)) (nth 1 xr-data)))
- (here-I-am (if rebuild
+ (here-I-am (if rebuild
(get 'reftex-toc :reftex-data)
(car (reftex-where-am-I))))
offset)
@@ -137,8 +138,14 @@ When called with a raw C-u prefix, rescan the document first."
(when (or (not reftex-toc-keep-other-windows)
(< (window-height) (* 2 window-min-height)))
(delete-other-windows))
- (setq reftex-last-window-height (window-height)) ; remember
- (split-window)
+
+ (setq reftex-last-window-width (window-width)
+ reftex-last-window-height (window-height)) ; remember
+ (if reftex-toc-split-windows-horizontally
+ (split-window-horizontally
+ (floor (* (frame-width) reftex-toc-split-windows-horizontally-fraction)))
+ (split-window))
+
(let ((default-major-mode 'reftex-toc-mode))
(switch-to-buffer "*toc*")))
@@ -237,9 +244,13 @@ SPC=view TAB=goto RET=goto+hide [q]uit [r]escan [l]abels [f]ollow [x]r [?]Help
(defun reftex-re-enlarge ()
;; Enlarge windiw to a remembered size
- (enlarge-window
- (max 0 (- (or reftex-last-window-height (window-height))
- (window-height)))))
+ (if reftex-toc-split-windows-horizontally
+ (enlarge-window-horizontally
+ (max 0 (- (or reftex-last-window-width (window-width))
+ (window-width))))
+ (enlarge-window
+ (max 0 (- (or reftex-last-window-height (window-height))
+ (window-height))))))
(defun reftex-toc-show-help ()
"Show a summary of special key bindings."
diff --git a/lisp/textmodes/reftex-vars.el b/lisp/textmodes/reftex-vars.el
index eac9d644d6..05588d712e 100644
--- a/lisp/textmodes/reftex-vars.el
+++ b/lisp/textmodes/reftex-vars.el
@@ -1,8 +1,8 @@
;;; reftex-vars.el --- configuration variables for RefTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; This file is part of GNU Emacs.
@@ -136,7 +136,8 @@ distribution. Mixed-case symbols are convenience aliases.")
(?s . "\\citep[see][]{%l}")
(?a . "\\citeauthor{%l}")
(?A . "\\citeauthor*{%l}")
- (?y . "\\citeyear{%l}")))
+ (?y . "\\citeyear{%l}")
+ (?n . "\\nocite{%l}")))
(bibentry "The Bibentry package"
"\\bibentry{%l}")
(harvard "The Harvard package"
@@ -205,12 +206,57 @@ distribution. Mixed-case symbols are convenience aliases.")
:prefix "reftex-"
:group 'tex)
+
;; Table of contents configuration --------------------------------------
(defgroup reftex-table-of-contents-browser nil
"A multifile table of contents browser."
:group 'reftex)
+(defcustom reftex-include-file-commands '("include" "input")
+ "LaTeX commands which input another file.
+The file name is expected after the command, either in braces or separated
+by whitespace."
+ :group 'reftex-table-of-contents-browser
+ :type '(repeat string))
+
+(defcustom reftex-max-section-depth 12
+ "Maximum depth of section levels in document structure.
+Standard LaTeX needs default is 7, but there are packages for which this
+needs to be larger."
+ :group 'reftex-table-of-contents-browser
+ :type 'integer)
+
+;; LaTeX section commands and level numbers
+(defcustom reftex-section-levels
+ '(
+ ("part" . 0)
+ ("chapter" . 1)
+ ("section" . 2)
+ ("subsection" . 3)
+ ("subsubsection" . 4)
+ ("paragraph" . 5)
+ ("subparagraph" . 6)
+ ("subsubparagraph" . 7)
+ ("addchap" . -1) ; KOMA-Script
+ ("addsec" . -2) ; KOMA-Script
+;;; ("minisec" . -7) ; KOMA-Script
+ )
+ "Commands and levels used for defining sections in the document.
+This is an alist with each element like (COMMAND-NAME . LEVEL).
+The car of each cons cell is the name of the section macro (without
+the backslash). The cdr is a number indicating its level. A negative
+level means the same level as the positive value, but the section will
+never get a number. The cdr may also be a function which will be called
+to after the section-re matched to determine the level."
+ :group 'reftex-table-of-contents-browser
+ :set 'reftex-set-dirty
+ :type '(repeat
+ (cons (string :tag "sectioning macro" "")
+ (choice
+ (number :tag "level " 0)
+ (symbol :tag "function " my-level-func)))))
+
(defcustom reftex-toc-max-level 100
"*The maximum level of toc entries which will be included in the TOC.
Section headings with a bigger level will be ignored. In RefTeX, chapters
@@ -219,6 +265,17 @@ This variable can be changed from within the *toc* buffer with the `t' key."
:group 'reftex-table-of-contents-browser
:type 'integer)
+(defcustom reftex-toc-split-windows-horizontally nil
+ "*Non-nil means, create TOC window by splitting window horizontally."
+ :group 'reftex-table-of-contents-browser
+ :type 'boolean)
+
+(defcustom reftex-toc-split-windows-horizontally-fraction .5
+ "*Fraction of the horizontal width of the frame to be used for TOC window.
+Only relevant when `reftex-toc-split-windows-horizontally' is non-nil."
+ :group 'reftex-table-of-contents-browser
+ :type 'number)
+
(defcustom reftex-toc-keep-other-windows t
"*Non-nil means, split the selected window to display the *toc* buffer.
This helps to keep the window configuration, but makes the *toc* small.
@@ -479,43 +536,6 @@ list. However, builtin defaults should normally be set with the variable
(nth 0 x)))
reftex-label-alist-builtin)))))
-(defcustom reftex-max-section-depth 12
- "Maximum depth of section levels in document structure.
-Standard LaTeX needs default is 7, but there are packages for which this
-needs to be larger."
- :group 'reftex-defining-label-environments
- :type 'integer)
-
-;; LaTeX section commands and level numbers
-(defcustom reftex-section-levels
- '(
- ("part" . 0)
- ("chapter" . 1)
- ("section" . 2)
- ("subsection" . 3)
- ("subsubsection" . 4)
- ("paragraph" . 5)
- ("subparagraph" . 6)
- ("subsubparagraph" . 7)
- ("addchap" . -1) ; KOMA-Script
- ("addsec" . -2) ; KOMA-Script
-;;; ("minisec" . -7) ; KOMA-Script
- )
- "Commands and levels used for defining sections in the document.
-This is an alist with each element like (COMMAND-NAME . LEVEL).
-The car of each cons cell is the name of the section macro (without
-the backslash). The cdr is a number indicating its level. A negative
-level means the same level as the positive value, but the section will
-never get a number. The cdr may also be a function which will be called
-to after the section-re matched to determine the level."
- :group 'reftex-defining-label-environments
- :set 'reftex-set-dirty
- :type '(repeat
- (cons (string :tag "sectioning macro" "")
- (choice
- (number :tag "level " 0)
- (symbol :tag "function " my-level-func)))))
-
(defcustom reftex-section-prefixes '((0 . "part:") (1 . "cha:") (t . "sec:"))
"Prefixes for section labels.
When the label prefix given in an entry in `reftex-label-alist' contains `%S',
@@ -855,6 +875,12 @@ string to insert into the buffer."
"Support for referencing bibliographic data with BibTeX."
:group 'reftex)
+(defcustom reftex-bibliography-commands '("bibliography" "nobibliography")
+ "LaTeX commands which specify the BibTeX databases to use with the document."
+ :group 'reftex-citation-support
+ :type '(repeat string))
+
+
(defvar reftex-bibfile-ignore-list nil) ; compatibility
(defcustom reftex-bibfile-ignore-regexps nil
"*List of regular expressions to exclude files in \\bibliography{..}.
@@ -898,7 +924,7 @@ If `reftex-cite-format' is a string, it will be used as the format.
In the format, the following percent escapes will be expanded.
%l The BibTeX label of the citation.
-%a List of author names, see also `reftex-cite-punctuation.
+%a List of author names, see also `reftex-cite-punctuation'.
%2a Like %a, but abbreviate more than 2 authors like Jones et al.
%A First author name only.
%e Works like %a, but on list of editor names. (%2e and %E work a well)
@@ -1175,6 +1201,14 @@ at one of these points, no word boundary is required there."
:group 'reftex-index-support
:type 'boolean)
+(defcustom reftex-index-verify-function nil
+ "A function which is called at each match during global indexing.
+If the function returns nil, the current match is skipped."
+ :group 'reftex-index-support
+ :type '(choice
+ (const :tag "No verification" nil)
+ (function)))
+
(defcustom reftex-index-phrases-skip-indexed-matches nil
"*Non-nil means, skip matches which appear to be indexed already.
When doing global indexing from the phrases buffer, searches for some
diff --git a/lisp/textmodes/reftex.el b/lisp/textmodes/reftex.el
index 8db74a4109..2dca200c0e 100644
--- a/lisp/textmodes/reftex.el
+++ b/lisp/textmodes/reftex.el
@@ -1,8 +1,8 @@
;;; reftex.el --- minor mode for doing \label, \ref, \cite, \index in LaTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
;; Author: Carsten Dominik <[email protected]>
;; Version: 4.16
;; Keywords: tex
;; This file is part of GNU Emacs.
@@ -300,7 +300,7 @@
;;; Define the formal stuff for a minor mode named RefTeX.
;;;
-(defconst reftex-version "RefTeX version 4.16"
+(defconst reftex-version "RefTeX version 4.17"
"Version string for RefTeX.")
(defvar reftex-mode nil
@@ -312,6 +312,7 @@
(defvar reftex-mode-menu nil)
(defvar reftex-syntax-table nil)
+(defvar reftex-syntax-table-for-bib nil)
(defvar reftex-auto-view-crossref-timer nil
"The timer used for auto-view-crossref.")
@@ -371,6 +372,12 @@ on the menu bar.
(setq reftex-syntax-table (copy-syntax-table (syntax-table)))
(modify-syntax-entry ?\( "." reftex-syntax-table)
(modify-syntax-entry ?\) "." reftex-syntax-table))
+ (unless reftex-syntax-table-for-bib
+ (setq reftex-syntax-table-for-bib (copy-syntax-table reftex-syntax-table))
+ (modify-syntax-entry ?\' "." reftex-syntax-table-for-bib)
+ (modify-syntax-entry ?\" "." reftex-syntax-table-for-bib)
+ (modify-syntax-entry ?\[ "." reftex-syntax-table-for-bib)
+ (modify-syntax-entry ?\] "." reftex-syntax-table-for-bib))
(run-hooks 'reftex-mode-hook))
;; Mode was turned off
(easy-menu-remove reftex-mode-menu)))
@@ -610,49 +617,49 @@ the label information is recompiled on next use."
;; The following constants are derived from `reftex-label-alist'.
;; Prompt used for label type queries directed to the user.
-(defconst reftex-type-query-prompt nil)
+(defvar reftex-type-query-prompt nil)
;; Help string for label type queries.
-(defconst reftex-type-query-help nil)
+(defvar reftex-type-query-help nil)
;; Alist relating label type to reference format.
-(defconst reftex-typekey-to-format-alist nil)
+(defvar reftex-typekey-to-format-alist nil)
;; Alist relating label type to label prefix.
-(defconst reftex-typekey-to-prefix-alist nil)
+(defvar reftex-typekey-to-prefix-alist nil)
;; Alist relating environments or macros to label type and context regexp.
-(defconst reftex-env-or-mac-alist nil)
+(defvar reftex-env-or-mac-alist nil)
;; List of special environment parser functions
-(defconst reftex-special-env-parsers nil)
+(defvar reftex-special-env-parsers nil)
;; List of macros carrying a label.
-(defconst reftex-label-mac-list nil)
+(defvar reftex-label-mac-list nil)
;; List of environments carrying a label.
-(defconst reftex-label-env-list nil)
+(defvar reftex-label-env-list nil)
;; List of all typekey letters in use.
-(defconst reftex-typekey-list nil)
+(defvar reftex-typekey-list nil)
;; Alist relating magic words to a label type.
-(defconst reftex-words-to-typekey-alist nil)
+(defvar reftex-words-to-typekey-alist nil)
;; The last list-of-labels entry used in a reference.
(defvar reftex-last-used-reference (list nil nil nil nil))
;; Alist relating index macros to other info.
-(defconst reftex-key-to-index-macro-alist nil)
+(defvar reftex-key-to-index-macro-alist nil)
;; Prompt for index macro queries
-(defconst reftex-query-index-macro-prompt nil)
+(defvar reftex-query-index-macro-prompt nil)
;; Help string for index macro queries
-(defconst reftex-query-index-macro-help nil)
+(defvar reftex-query-index-macro-help nil)
;; The message when follow-mode is suspended
-(defconst reftex-no-follow-message
+(defvar reftex-no-follow-message
"No follow-mode into unvisited file. Press SPC to visit it.")
-(defconst reftex-no-info-message
+(defvar reftex-no-info-message
"%s: info not available, use `\\[reftex-view-crossref]' to get it.")
;; Global variables used for communication between functions.
@@ -1092,9 +1099,15 @@ This enforces rescanning the buffer on next use."
reftex-section-levels))
;; Calculate the regular expressions
- (let* ((wbol "\\(\\`\\|[\n\r]\\)[ \t]*")
+ (let* (
+; (wbol "\\(\\`\\|[\n\r]\\)[ \t]*")
+ (wbol "\\(\\`\\|[\n\r]\\)[ \t]*")
(label-re "\\\\label{\\([^}]*\\)}")
- (include-re (concat wbol "\\\\\\(include\\|input\\)[{ \t]+\\([^} \t\n\r]+\\)"))
+ (include-re (concat wbol
+ "\\\\\\("
+ (mapconcat 'identity
+ reftex-include-file-commands "\\|")
+ "\\)[{ \t]+\\([^} \t\n\r]+\\)"))
(section-re
(concat wbol "\\\\\\("
(mapconcat (lambda (x) (regexp-quote (car x)))
@@ -1,8 +1,8 @@
;;; reftex.el --- minor mode for doing \label, \ref, \cite, \index in LaTeX
;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-;; Author: Carsten Dominik <[email protected]>
-;; Version: 4.16
+;; Author: Carsten Dominik <[email protected]>
+;; Version: 4.17
;; Keywords: tex
;; This file is part of GNU Emacs.